WidgetPlacement enum
Values
- swaggerGeneratedUnknown → const WidgetPlacement
-
const WidgetPlacement(null) - topLeft → const WidgetPlacement
-
const WidgetPlacement('top-left') - top → const WidgetPlacement
-
const WidgetPlacement('top') - topRight → const WidgetPlacement
-
const WidgetPlacement('top-right') - bottomLeft → const WidgetPlacement
-
const WidgetPlacement('bottom-left') - bottom → const WidgetPlacement
-
const WidgetPlacement('bottom') - bottomRight → const WidgetPlacement
-
const WidgetPlacement('bottom-right')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WidgetPlacement> - A constant List of the values in this enum, in order of their declaration.