AdditionalFormatResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AdditionalFormatResponseModel({required String requestedFormat, required String fileExtension, required String contentType, required bool isBase64Encoded, required String content})
const
AdditionalFormatResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

content String
final
contentType String
final
fileExtension String
final
hashCode int
The hash code for this object.
no setteroverride
isBase64Encoded bool
final
requestedFormat String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? requestedFormat, String? fileExtension, String? contentType, bool? isBase64Encoded, String? content}) AdditionalFormatResponseModel

Available on AdditionalFormatResponseModel, provided by the $AdditionalFormatResponseModelExtension extension

copyWithWrapped({Wrapped<String>? requestedFormat, Wrapped<String>? fileExtension, Wrapped<String>? contentType, Wrapped<bool>? isBase64Encoded, Wrapped<String>? content}) AdditionalFormatResponseModel

Available on AdditionalFormatResponseModel, provided by the $AdditionalFormatResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AdditionalFormatResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AdditionalFormatResponseModel instance)