AgentConfigDBModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AgentConfigDBModel({String? firstMessage, String? language, DynamicVariablesConfig? dynamicVariables, PromptAgentDBModel? prompt})
const
AgentConfigDBModel.fromJson(Map<String, dynamic> json)
factory

Properties

dynamicVariables DynamicVariablesConfig?
final
firstMessage String?
final
hashCode int
The hash code for this object.
no setteroverride
language String?
final
prompt PromptAgentDBModel?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? firstMessage, String? language, DynamicVariablesConfig? dynamicVariables, PromptAgentDBModel? prompt}) AgentConfigDBModel

Available on AgentConfigDBModel, provided by the $AgentConfigDBModelExtension extension

copyWithWrapped({Wrapped<String?>? firstMessage, Wrapped<String?>? language, Wrapped<DynamicVariablesConfig?>? dynamicVariables, Wrapped<PromptAgentDBModel?>? prompt}) AgentConfigDBModel

Available on AgentConfigDBModel, provided by the $AgentConfigDBModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AgentConfigDBModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AgentConfigDBModel instance)