AgentConfigOverrideConfig class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AgentConfigOverrideConfig({bool? firstMessage, bool? language, PromptAgentOverrideConfig? prompt})
const
AgentConfigOverrideConfig.fromJson(Map<String, dynamic> json)
factory

Properties

firstMessage bool?
final
hashCode int
The hash code for this object.
no setteroverride
language bool?
final
prompt PromptAgentOverrideConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? firstMessage, bool? language, PromptAgentOverrideConfig? prompt}) AgentConfigOverrideConfig

Available on AgentConfigOverrideConfig, provided by the $AgentConfigOverrideConfigExtension extension

copyWithWrapped({Wrapped<bool?>? firstMessage, Wrapped<bool?>? language, Wrapped<PromptAgentOverrideConfig?>? prompt}) AgentConfigOverrideConfig

Available on AgentConfigOverrideConfig, provided by the $AgentConfigOverrideConfigExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AgentConfigOverrideConfig Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AgentConfigOverrideConfig instance)