BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost({required String name, dynamic file, dynamic description, dynamic workspaceAccess})
const
BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost.fromJson(Map<String, dynamic> json)
factory

Properties

description → dynamic
final
file → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceAccess → dynamic
final

Methods

copyWith({String? name, dynamic file, dynamic description, dynamic workspaceAccess}) BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost

Available on BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost, provided by the $BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePostExtension extension

copyWithWrapped({Wrapped<String>? name, Wrapped? file, Wrapped? description, Wrapped? workspaceAccess}) BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost

Available on BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePost, provided by the $BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromFilePostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override