BodyAddVoiceV1VoicesAddPost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BodyAddVoiceV1VoicesAddPost({required String name, required List<String> files, bool? removeBackgroundNoise, dynamic description, dynamic labels})
const
BodyAddVoiceV1VoicesAddPost.fromJson(Map<String, dynamic> json)
factory

Properties

description → dynamic
final
files List<String>
final
hashCode int
The hash code for this object.
no setteroverride
labels → dynamic
final
name String
final
removeBackgroundNoise bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, List<String>? files, bool? removeBackgroundNoise, dynamic description, dynamic labels}) BodyAddVoiceV1VoicesAddPost

Available on BodyAddVoiceV1VoicesAddPost, provided by the $BodyAddVoiceV1VoicesAddPostExtension extension

copyWithWrapped({Wrapped<String>? name, Wrapped<List<String>>? files, Wrapped<bool?>? removeBackgroundNoise, Wrapped? description, Wrapped? labels}) BodyAddVoiceV1VoicesAddPost

Available on BodyAddVoiceV1VoicesAddPost, provided by the $BodyAddVoiceV1VoicesAddPostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BodyAddVoiceV1VoicesAddPost Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BodyAddVoiceV1VoicesAddPost instance)