BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

hashCode int
The hash code for this object.
no setteroverride
name → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

copyWith({String? url, dynamic name}) BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPost

Available on BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPost, provided by the $BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPostExtension extension

copyWithWrapped({Wrapped<String>? url, Wrapped? name}) BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPost

Available on BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPost, provided by the $BodyCreateURLDocumentV1ConvaiKnowledgeBaseUrlPostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override