BodyEditPVCVoiceV1VoicesPvcVoiceIdPost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BodyEditPVCVoiceV1VoicesPvcVoiceIdPost({String? name, String? language, dynamic description, dynamic labels})
const
BodyEditPVCVoiceV1VoicesPvcVoiceIdPost.fromJson(Map<String, dynamic> json)
factory

Properties

description → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
labels → dynamic
final
language String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? language, dynamic description, dynamic labels}) BodyEditPVCVoiceV1VoicesPvcVoiceIdPost

Available on BodyEditPVCVoiceV1VoicesPvcVoiceIdPost, provided by the $BodyEditPVCVoiceV1VoicesPvcVoiceIdPostExtension extension

copyWithWrapped({Wrapped<String?>? name, Wrapped<String?>? language, Wrapped? description, Wrapped? labels}) BodyEditPVCVoiceV1VoicesPvcVoiceIdPost

Available on BodyEditPVCVoiceV1VoicesPvcVoiceIdPost, provided by the $BodyEditPVCVoiceV1VoicesPvcVoiceIdPostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BodyEditPVCVoiceV1VoicesPvcVoiceIdPost Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BodyEditPVCVoiceV1VoicesPvcVoiceIdPost instance)