BodyInviteUserV1WorkspaceInvitesAddPost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BodyInviteUserV1WorkspaceInvitesAddPost({required String email, dynamic groupIds, dynamic workspacePermission})
const
BodyInviteUserV1WorkspaceInvitesAddPost.fromJson(Map<String, dynamic> json)
factory

Properties

email String
final
groupIds → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspacePermission → dynamic
final

Methods

copyWith({String? email, dynamic groupIds, dynamic workspacePermission}) BodyInviteUserV1WorkspaceInvitesAddPost

Available on BodyInviteUserV1WorkspaceInvitesAddPost, provided by the $BodyInviteUserV1WorkspaceInvitesAddPostExtension extension

copyWithWrapped({Wrapped<String>? email, Wrapped? groupIds, Wrapped? workspacePermission}) BodyInviteUserV1WorkspaceInvitesAddPost

Available on BodyInviteUserV1WorkspaceInvitesAddPost, provided by the $BodyInviteUserV1WorkspaceInvitesAddPostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BodyInviteUserV1WorkspaceInvitesAddPost Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BodyInviteUserV1WorkspaceInvitesAddPost instance)