BodySpeechToTextV1SpeechToTextPost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BodySpeechToTextV1SpeechToTextPost({required String modelId, dynamic file, dynamic languageCode, bool? tagAudioEvents, dynamic numSpeakers, BodySpeechToTextV1SpeechToTextPostTimestampsGranularity? timestampsGranularity, bool? diarize, List<ExportOptions>? additionalFormats, BodySpeechToTextV1SpeechToTextPostFileFormat? fileFormat, dynamic cloudStorageUrl, bool? webhook})
const
BodySpeechToTextV1SpeechToTextPost.fromJson(Map<String, dynamic> json)
factory

Properties

additionalFormats List<ExportOptions>?
final
cloudStorageUrl → dynamic
final
diarize bool?
final
file → dynamic
final
fileFormat BodySpeechToTextV1SpeechToTextPostFileFormat?
final
hashCode int
The hash code for this object.
no setteroverride
languageCode → dynamic
final
modelId String
final
numSpeakers → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagAudioEvents bool?
final
timestampsGranularity BodySpeechToTextV1SpeechToTextPostTimestampsGranularity?
final
webhook bool?
final

Methods

copyWith({String? modelId, dynamic file, dynamic languageCode, bool? tagAudioEvents, dynamic numSpeakers, BodySpeechToTextV1SpeechToTextPostTimestampsGranularity? timestampsGranularity, bool? diarize, List<ExportOptions>? additionalFormats, BodySpeechToTextV1SpeechToTextPostFileFormat? fileFormat, dynamic cloudStorageUrl, bool? webhook}) BodySpeechToTextV1SpeechToTextPost

Available on BodySpeechToTextV1SpeechToTextPost, provided by the $BodySpeechToTextV1SpeechToTextPostExtension extension

copyWithWrapped({Wrapped<String>? modelId, Wrapped? file, Wrapped? languageCode, Wrapped<bool?>? tagAudioEvents, Wrapped? numSpeakers, Wrapped<BodySpeechToTextV1SpeechToTextPostTimestampsGranularity?>? timestampsGranularity, Wrapped<bool?>? diarize, Wrapped<List<ExportOptions>?>? additionalFormats, Wrapped<BodySpeechToTextV1SpeechToTextPostFileFormat?>? fileFormat, Wrapped? cloudStorageUrl, Wrapped<bool?>? webhook}) BodySpeechToTextV1SpeechToTextPost

Available on BodySpeechToTextV1SpeechToTextPost, provided by the $BodySpeechToTextV1SpeechToTextPostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BodySpeechToTextV1SpeechToTextPost Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BodySpeechToTextV1SpeechToTextPost instance)