BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost({required WorkspaceResourceType resourceType, dynamic userEmail, dynamic groupId, dynamic workspaceApiKeyId})
const
BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost.fromJson(Map<String, dynamic> json)
factory

Properties

groupId → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
resourceType WorkspaceResourceType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userEmail → dynamic
final
workspaceApiKeyId → dynamic
final

Methods

copyWith({WorkspaceResourceType? resourceType, dynamic userEmail, dynamic groupId, dynamic workspaceApiKeyId}) BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost

Available on BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost, provided by the $BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePostExtension extension

copyWithWrapped({Wrapped<WorkspaceResourceType>? resourceType, Wrapped? userEmail, Wrapped? groupId, Wrapped? workspaceApiKeyId}) BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost

Available on BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePost, provided by the $BodyUnshareWorkspaceResourceV1WorkspaceResourcesResourceIdUnsharePostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override