ChapterContentBlockResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ChapterContentBlockResponseModel({required String blockId, required List<Object> nodes})
const
ChapterContentBlockResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

blockId String
final
hashCode int
The hash code for this object.
no setteroverride
nodes List<Object>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? blockId, List<Object>? nodes}) ChapterContentBlockResponseModel

Available on ChapterContentBlockResponseModel, provided by the $ChapterContentBlockResponseModelExtension extension

copyWithWrapped({Wrapped<String>? blockId, Wrapped<List<Object>>? nodes}) ChapterContentBlockResponseModel

Available on ChapterContentBlockResponseModel, provided by the $ChapterContentBlockResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ChapterContentBlockResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ChapterContentBlockResponseModel instance)