ChapterSnapshotResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ChapterSnapshotResponseModel({required String chapterSnapshotId, required String projectId, required String chapterId, required int createdAtUnix, required String name})
-
const
-
ChapterSnapshotResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- chapterId → String
-
final
- chapterSnapshotId → String
-
final
- createdAtUnix → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- projectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? chapterSnapshotId, String? projectId, String? chapterId, int? createdAtUnix, String? name}) → ChapterSnapshotResponseModel -
Available on ChapterSnapshotResponseModel, provided by the $ChapterSnapshotResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? chapterSnapshotId, Wrapped<String> ? projectId, Wrapped<String> ? chapterId, Wrapped<int> ? createdAtUnix, Wrapped<String> ? name}) → ChapterSnapshotResponseModel -
Available on ChapterSnapshotResponseModel, provided by the $ChapterSnapshotResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ChapterSnapshotResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ChapterSnapshotResponseModel instance)