ClientToolConfigOutput class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ClientToolConfigOutput({String? id, required String name, required String description, int? responseTimeoutSecs, String? type, dynamic parameters, bool? expectsResponse, DynamicVariablesConfig? dynamicVariables})
-
const
-
ClientToolConfigOutput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
final
- dynamicVariables → DynamicVariablesConfig?
-
final
- expectsResponse → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String?
-
final
- name → String
-
final
- parameters → dynamic
-
final
- responseTimeoutSecs → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
Methods
-
copyWith(
{String? id, String? name, String? description, int? responseTimeoutSecs, String? type, dynamic parameters, bool? expectsResponse, DynamicVariablesConfig? dynamicVariables}) → ClientToolConfigOutput -
Available on ClientToolConfigOutput, provided by the $ClientToolConfigOutputExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? id, Wrapped<String> ? name, Wrapped<String> ? description, Wrapped<int?> ? responseTimeoutSecs, Wrapped<String?> ? type, Wrapped? parameters, Wrapped<bool?> ? expectsResponse, Wrapped<DynamicVariablesConfig?> ? dynamicVariables}) → ClientToolConfigOutput -
Available on ClientToolConfigOutput, provided by the $ClientToolConfigOutputExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ClientToolConfigOutput Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ClientToolConfigOutput instance)