ConvAIStoredSecretDependencies class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConvAIStoredSecretDependencies({required List<Object> tools, required List<Object> agentTools, required List<SecretDependencyType> others, List<DependentPhoneNumberIdentifier>? phoneNumbers})
const
ConvAIStoredSecretDependencies.fromJson(Map<String, dynamic> json)
factory

Properties

agentTools List<Object>
final
hashCode int
The hash code for this object.
no setteroverride
others List<SecretDependencyType>
final
phoneNumbers List<DependentPhoneNumberIdentifier>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<Object>
final

Methods

copyWith({List<Object>? tools, List<Object>? agentTools, List<SecretDependencyType>? others, List<DependentPhoneNumberIdentifier>? phoneNumbers}) ConvAIStoredSecretDependencies

Available on ConvAIStoredSecretDependencies, provided by the $ConvAIStoredSecretDependenciesExtension extension

copyWithWrapped({Wrapped<List<Object>>? tools, Wrapped<List<Object>>? agentTools, Wrapped<List<SecretDependencyType>>? others, Wrapped<List<DependentPhoneNumberIdentifier>?>? phoneNumbers}) ConvAIStoredSecretDependencies

Available on ConvAIStoredSecretDependencies, provided by the $ConvAIStoredSecretDependenciesExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ConvAIStoredSecretDependencies Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ConvAIStoredSecretDependencies instance)