ConvAIWebhooks class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConvAIWebhooks({dynamic postCallWebhookId})
const
ConvAIWebhooks.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
postCallWebhookId → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic postCallWebhookId}) ConvAIWebhooks

Available on ConvAIWebhooks, provided by the $ConvAIWebhooksExtension extension

copyWithWrapped({Wrapped? postCallWebhookId}) ConvAIWebhooks

Available on ConvAIWebhooks, provided by the $ConvAIWebhooksExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ConvAIWebhooks Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ConvAIWebhooks instance)