ConversationInitiationClientDataConfigInput class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ConversationInitiationClientDataConfigInput({ConversationConfigClientOverrideConfigInput? conversationConfigOverride, bool? customLlmExtraBody, bool? enableConversationInitiationClientDataFromWebhook})
-
const
-
ConversationInitiationClientDataConfigInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- conversationConfigOverride → ConversationConfigClientOverrideConfigInput?
-
final
- customLlmExtraBody → bool?
-
final
- enableConversationInitiationClientDataFromWebhook → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ConversationConfigClientOverrideConfigInput? conversationConfigOverride, bool? customLlmExtraBody, bool? enableConversationInitiationClientDataFromWebhook}) → ConversationInitiationClientDataConfigInput -
Available on ConversationInitiationClientDataConfigInput, provided by the $ConversationInitiationClientDataConfigInputExtension extension
-
copyWithWrapped(
{Wrapped< ConversationConfigClientOverrideConfigInput?> ? conversationConfigOverride, Wrapped<bool?> ? customLlmExtraBody, Wrapped<bool?> ? enableConversationInitiationClientDataFromWebhook}) → ConversationInitiationClientDataConfigInput -
Available on ConversationInitiationClientDataConfigInput, provided by the $ConversationInitiationClientDataConfigInputExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationInitiationClientDataConfigInput Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationInitiationClientDataConfigInput instance)