ConversationInitiationClientDataConfigOutput class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ConversationInitiationClientDataConfigOutput({ConversationConfigClientOverrideConfigOutput? conversationConfigOverride, bool? customLlmExtraBody, bool? enableConversationInitiationClientDataFromWebhook})
-
const
-
ConversationInitiationClientDataConfigOutput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- conversationConfigOverride → ConversationConfigClientOverrideConfigOutput?
-
final
- customLlmExtraBody → bool?
-
final
- enableConversationInitiationClientDataFromWebhook → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ConversationConfigClientOverrideConfigOutput? conversationConfigOverride, bool? customLlmExtraBody, bool? enableConversationInitiationClientDataFromWebhook}) → ConversationInitiationClientDataConfigOutput -
Available on ConversationInitiationClientDataConfigOutput, provided by the $ConversationInitiationClientDataConfigOutputExtension extension
-
copyWithWrapped(
{Wrapped< ConversationConfigClientOverrideConfigOutput?> ? conversationConfigOverride, Wrapped<bool?> ? customLlmExtraBody, Wrapped<bool?> ? enableConversationInitiationClientDataFromWebhook}) → ConversationInitiationClientDataConfigOutput -
Available on ConversationInitiationClientDataConfigOutput, provided by the $ConversationInitiationClientDataConfigOutputExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationInitiationClientDataConfigOutput Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationInitiationClientDataConfigOutput instance)