ConversationSimulationSpecification class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ConversationSimulationSpecification({required AgentConfigDBModel simulatedUserConfig, Map<
String, dynamic> ? toolMockConfig, List<ConversationHistoryTranscriptCommonModelInput> ? partialConversationHistory}) -
const
-
ConversationSimulationSpecification.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
partialConversationHistory
→ List<
ConversationHistoryTranscriptCommonModelInput> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simulatedUserConfig → AgentConfigDBModel
-
final
-
toolMockConfig
→ Map<
String, dynamic> ? -
final
Methods
-
copyWith(
{AgentConfigDBModel? simulatedUserConfig, Map< String, dynamic> ? toolMockConfig, List<ConversationHistoryTranscriptCommonModelInput> ? partialConversationHistory}) → ConversationSimulationSpecification -
Available on ConversationSimulationSpecification, provided by the $ConversationSimulationSpecificationExtension extension
-
copyWithWrapped(
{Wrapped< AgentConfigDBModel> ? simulatedUserConfig, Wrapped<Map< ? toolMockConfig, Wrapped<String, dynamic> ?>List< ? partialConversationHistory}) → ConversationSimulationSpecificationConversationHistoryTranscriptCommonModelInput> ?> -
Available on ConversationSimulationSpecification, provided by the $ConversationSimulationSpecificationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationSimulationSpecification Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationSimulationSpecification instance)