CustomLLM class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CustomLLM({required String url, dynamic modelId, dynamic apiKey})
const
CustomLLM.fromJson(Map<String, dynamic> json)
factory

Properties

apiKey → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
modelId → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

copyWith({String? url, dynamic modelId, dynamic apiKey}) CustomLLM

Available on CustomLLM, provided by the $CustomLLMExtension extension

copyWithWrapped({Wrapped<String>? url, Wrapped? modelId, Wrapped? apiKey}) CustomLLM

Available on CustomLLM, provided by the $CustomLLMExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const CustomLLM Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CustomLLM instance)