DataCollectionResultCommonModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DataCollectionResultCommonModel({required String dataCollectionId, dynamic $value, dynamic jsonSchema, required String rationale})
const
DataCollectionResultCommonModel.fromJson(Map<String, dynamic> json)
factory

Properties

$value → dynamic
final
dataCollectionId String
final
hashCode int
The hash code for this object.
no setteroverride
jsonSchema → dynamic
final
rationale String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? dataCollectionId, dynamic $value, dynamic jsonSchema, String? rationale}) DataCollectionResultCommonModel

Available on DataCollectionResultCommonModel, provided by the $DataCollectionResultCommonModelExtension extension

copyWithWrapped({Wrapped<String>? dataCollectionId, Wrapped? $value, Wrapped? jsonSchema, Wrapped<String>? rationale}) DataCollectionResultCommonModel

Available on DataCollectionResultCommonModel, provided by the $DataCollectionResultCommonModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const DataCollectionResultCommonModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(DataCollectionResultCommonModel instance)