EditChapterResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EditChapterResponseModel({required ChapterWithContentResponseModel chapter})
const
EditChapterResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

chapter ChapterWithContentResponseModel
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChapterWithContentResponseModel? chapter}) EditChapterResponseModel

Available on EditChapterResponseModel, provided by the $EditChapterResponseModelExtension extension

copyWithWrapped({Wrapped<ChapterWithContentResponseModel>? chapter}) EditChapterResponseModel

Available on EditChapterResponseModel, provided by the $EditChapterResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const EditChapterResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(EditChapterResponseModel instance)