EndCallToolConfig class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EndCallToolConfig({String? systemToolType})
const
EndCallToolConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemToolType String?
final

Methods

copyWith({String? systemToolType}) EndCallToolConfig

Available on EndCallToolConfig, provided by the $EndCallToolConfigExtension extension

copyWithWrapped({Wrapped<String?>? systemToolType}) EndCallToolConfig

Available on EndCallToolConfig, provided by the $EndCallToolConfigExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const EndCallToolConfig Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(EndCallToolConfig instance)