GetKnowledgeBaseListResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
GetKnowledgeBaseListResponseModel({required List<
Object> documents, dynamic nextCursor, required bool hasMore}) -
const
-
GetKnowledgeBaseListResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
documents
→ List<
Object> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasMore → bool
-
final
- nextCursor → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< Object> ? documents, dynamic nextCursor, bool? hasMore}) → GetKnowledgeBaseListResponseModel -
Available on GetKnowledgeBaseListResponseModel, provided by the $GetKnowledgeBaseListResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< List< ? documents, Wrapped? nextCursor, Wrapped<Object> >bool> ? hasMore}) → GetKnowledgeBaseListResponseModel -
Available on GetKnowledgeBaseListResponseModel, provided by the $GetKnowledgeBaseListResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const GetKnowledgeBaseListResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(GetKnowledgeBaseListResponseModel instance)