GetLibraryVoicesResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GetLibraryVoicesResponseModel({required List<LibraryVoiceResponseModel> voices, required bool hasMore, dynamic lastSortId})
const
GetLibraryVoicesResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
hasMore bool
final
lastSortId → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voices List<LibraryVoiceResponseModel>
final

Methods

copyWith({List<LibraryVoiceResponseModel>? voices, bool? hasMore, dynamic lastSortId}) GetLibraryVoicesResponseModel

Available on GetLibraryVoicesResponseModel, provided by the $GetLibraryVoicesResponseModelExtension extension

copyWithWrapped({Wrapped<List<LibraryVoiceResponseModel>>? voices, Wrapped<bool>? hasMore, Wrapped? lastSortId}) GetLibraryVoicesResponseModel

Available on GetLibraryVoicesResponseModel, provided by the $GetLibraryVoicesResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const GetLibraryVoicesResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(GetLibraryVoicesResponseModel instance)