LLMInputOutputTokensUsage class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LLMInputOutputTokensUsage({LLMTokensCategoryUsage? input, LLMTokensCategoryUsage? inputCacheRead, LLMTokensCategoryUsage? inputCacheWrite, LLMTokensCategoryUsage? outputTotal})
const
LLMInputOutputTokensUsage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
input LLMTokensCategoryUsage?
final
inputCacheRead LLMTokensCategoryUsage?
final
inputCacheWrite LLMTokensCategoryUsage?
final
outputTotal LLMTokensCategoryUsage?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({LLMTokensCategoryUsage? input, LLMTokensCategoryUsage? inputCacheRead, LLMTokensCategoryUsage? inputCacheWrite, LLMTokensCategoryUsage? outputTotal}) LLMInputOutputTokensUsage

Available on LLMInputOutputTokensUsage, provided by the $LLMInputOutputTokensUsageExtension extension

copyWithWrapped({Wrapped<LLMTokensCategoryUsage?>? input, Wrapped<LLMTokensCategoryUsage?>? inputCacheRead, Wrapped<LLMTokensCategoryUsage?>? inputCacheWrite, Wrapped<LLMTokensCategoryUsage?>? outputTotal}) LLMInputOutputTokensUsage

Available on LLMInputOutputTokensUsage, provided by the $LLMInputOutputTokensUsageExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LLMInputOutputTokensUsage Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LLMInputOutputTokensUsage instance)