LanguageDetectionToolConfig class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LanguageDetectionToolConfig({String? systemToolType})
const
LanguageDetectionToolConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemToolType String?
final

Methods

copyWith({String? systemToolType}) LanguageDetectionToolConfig

Available on LanguageDetectionToolConfig, provided by the $LanguageDetectionToolConfigExtension extension

copyWithWrapped({Wrapped<String?>? systemToolType}) LanguageDetectionToolConfig

Available on LanguageDetectionToolConfig, provided by the $LanguageDetectionToolConfigExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LanguageDetectionToolConfig Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LanguageDetectionToolConfig instance)