LibraryVoiceResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LibraryVoiceResponseModel({required String publicOwnerId, required String voiceId, required int dateUnix, required String name, required String accent, required String gender, required String age, required String descriptive, required String useCase, required LibraryVoiceResponseModelCategory category, dynamic language, dynamic locale, dynamic description, dynamic previewUrl, required int usageCharacterCount1y, required int usageCharacterCount7d, required int playApiUsageCharacterCount1y, required int clonedByCount, dynamic rate, dynamic fiatRate, required bool freeUsersAllowed, required bool liveModerationEnabled, required bool featured, dynamic verifiedLanguages, dynamic noticePeriod, dynamic instagramUsername, dynamic twitterUsername, dynamic youtubeUsername, dynamic tiktokUsername, dynamic imageUrl, dynamic isAddedByUser})
const
LibraryVoiceResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

accent String
final
age String
final
category LibraryVoiceResponseModelCategory
final
clonedByCount int
final
dateUnix int
final
description → dynamic
final
descriptive String
final
final
fiatRate → dynamic
final
freeUsersAllowed bool
final
gender String
final
hashCode int
The hash code for this object.
no setteroverride
imageUrl → dynamic
final
instagramUsername → dynamic
final
isAddedByUser → dynamic
final
language → dynamic
final
liveModerationEnabled bool
final
locale → dynamic
final
name String
final
noticePeriod → dynamic
final
playApiUsageCharacterCount1y int
final
previewUrl → dynamic
final
publicOwnerId String
final
rate → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiktokUsername → dynamic
final
twitterUsername → dynamic
final
usageCharacterCount1y int
final
usageCharacterCount7d int
final
useCase String
final
verifiedLanguages → dynamic
final
voiceId String
final
youtubeUsername → dynamic
final

Methods

copyWith({String? publicOwnerId, String? voiceId, int? dateUnix, String? name, String? accent, String? gender, String? age, String? descriptive, String? useCase, LibraryVoiceResponseModelCategory? category, dynamic language, dynamic locale, dynamic description, dynamic previewUrl, int? usageCharacterCount1y, int? usageCharacterCount7d, int? playApiUsageCharacterCount1y, int? clonedByCount, dynamic rate, dynamic fiatRate, bool? freeUsersAllowed, bool? liveModerationEnabled, bool? featured, dynamic verifiedLanguages, dynamic noticePeriod, dynamic instagramUsername, dynamic twitterUsername, dynamic youtubeUsername, dynamic tiktokUsername, dynamic imageUrl, dynamic isAddedByUser}) LibraryVoiceResponseModel

Available on LibraryVoiceResponseModel, provided by the $LibraryVoiceResponseModelExtension extension

copyWithWrapped({Wrapped<String>? publicOwnerId, Wrapped<String>? voiceId, Wrapped<int>? dateUnix, Wrapped<String>? name, Wrapped<String>? accent, Wrapped<String>? gender, Wrapped<String>? age, Wrapped<String>? descriptive, Wrapped<String>? useCase, Wrapped<LibraryVoiceResponseModelCategory>? category, Wrapped? language, Wrapped? locale, Wrapped? description, Wrapped? previewUrl, Wrapped<int>? usageCharacterCount1y, Wrapped<int>? usageCharacterCount7d, Wrapped<int>? playApiUsageCharacterCount1y, Wrapped<int>? clonedByCount, Wrapped? rate, Wrapped? fiatRate, Wrapped<bool>? freeUsersAllowed, Wrapped<bool>? liveModerationEnabled, Wrapped<bool>? featured, Wrapped? verifiedLanguages, Wrapped? noticePeriod, Wrapped? instagramUsername, Wrapped? twitterUsername, Wrapped? youtubeUsername, Wrapped? tiktokUsername, Wrapped? imageUrl, Wrapped? isAddedByUser}) LibraryVoiceResponseModel

Available on LibraryVoiceResponseModel, provided by the $LibraryVoiceResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LibraryVoiceResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LibraryVoiceResponseModel instance)