ModelRatesResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ModelRatesResponseModel({required double characterCostMultiplier})
const
ModelRatesResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

characterCostMultiplier double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? characterCostMultiplier}) ModelRatesResponseModel

Available on ModelRatesResponseModel, provided by the $ModelRatesResponseModelExtension extension

copyWithWrapped({Wrapped<double>? characterCostMultiplier}) ModelRatesResponseModel

Available on ModelRatesResponseModel, provided by the $ModelRatesResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ModelRatesResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ModelRatesResponseModel instance)