ModelSettingsResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ModelSettingsResponseModel({dynamic stability, dynamic similarityBoost})
const
ModelSettingsResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
similarityBoost → dynamic
final
stability → dynamic
final

Methods

copyWith({dynamic stability, dynamic similarityBoost}) ModelSettingsResponseModel

Available on ModelSettingsResponseModel, provided by the $ModelSettingsResponseModelExtension extension

copyWithWrapped({Wrapped? stability, Wrapped? similarityBoost}) ModelSettingsResponseModel

Available on ModelSettingsResponseModel, provided by the $ModelSettingsResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ModelSettingsResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ModelSettingsResponseModel instance)