NativeMCPToolConfigOutput class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NativeMCPToolConfigOutput({String? id, required String name, required String description, int? responseTimeoutSecs, String? type, dynamic parameters, required String mcpToolName, required String mcpServerId, MCPApprovalRequiredModel? approvalMode})
const
NativeMCPToolConfigOutput.fromJson(Map<String, dynamic> json)
factory

Properties

approvalMode MCPApprovalRequiredModel?
final
description String
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
mcpServerId String
final
mcpToolName String
final
name String
final
parameters → dynamic
final
responseTimeoutSecs int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

copyWith({String? id, String? name, String? description, int? responseTimeoutSecs, String? type, dynamic parameters, String? mcpToolName, String? mcpServerId, MCPApprovalRequiredModel? approvalMode}) NativeMCPToolConfigOutput

Available on NativeMCPToolConfigOutput, provided by the $NativeMCPToolConfigOutputExtension extension

copyWithWrapped({Wrapped<String?>? id, Wrapped<String>? name, Wrapped<String>? description, Wrapped<int?>? responseTimeoutSecs, Wrapped<String?>? type, Wrapped? parameters, Wrapped<String>? mcpToolName, Wrapped<String>? mcpServerId, Wrapped<MCPApprovalRequiredModel?>? approvalMode}) NativeMCPToolConfigOutput

Available on NativeMCPToolConfigOutput, provided by the $NativeMCPToolConfigOutputExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const NativeMCPToolConfigOutput Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(NativeMCPToolConfigOutput instance)