PhoneNumberAgentInfo class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PhoneNumberAgentInfo({required String agentId, required String agentName})
const
PhoneNumberAgentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String
final
agentName String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? agentId, String? agentName}) PhoneNumberAgentInfo

Available on PhoneNumberAgentInfo, provided by the $PhoneNumberAgentInfoExtension extension

copyWithWrapped({Wrapped<String>? agentId, Wrapped<String>? agentName}) PhoneNumberAgentInfo

Available on PhoneNumberAgentInfo, provided by the $PhoneNumberAgentInfoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const PhoneNumberAgentInfo Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PhoneNumberAgentInfo instance)