PostWorkspaceSecretRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PostWorkspaceSecretRequest({required String type, required String name, required String $value})
const
PostWorkspaceSecretRequest.fromJson(Map<String, dynamic> json)
factory

Properties

$value String
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({String? type, String? name, String? $value}) PostWorkspaceSecretRequest

Available on PostWorkspaceSecretRequest, provided by the $PostWorkspaceSecretRequestExtension extension

copyWithWrapped({Wrapped<String>? type, Wrapped<String>? name, Wrapped<String>? $value}) PostWorkspaceSecretRequest

Available on PostWorkspaceSecretRequest, provided by the $PostWorkspaceSecretRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const PostWorkspaceSecretRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PostWorkspaceSecretRequest instance)