PostWorkspaceSecretResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PostWorkspaceSecretResponseModel({required String type, required String secretId, required String name})
const
PostWorkspaceSecretResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretId String
final
type String
final

Methods

copyWith({String? type, String? secretId, String? name}) PostWorkspaceSecretResponseModel

Available on PostWorkspaceSecretResponseModel, provided by the $PostWorkspaceSecretResponseModelExtension extension

copyWithWrapped({Wrapped<String>? type, Wrapped<String>? secretId, Wrapped<String>? name}) PostWorkspaceSecretResponseModel

Available on PostWorkspaceSecretResponseModel, provided by the $PostWorkspaceSecretResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const PostWorkspaceSecretResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PostWorkspaceSecretResponseModel instance)