ProjectSnapshotResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ProjectSnapshotResponseModel({required String projectSnapshotId, required String projectId, required int createdAtUnix, required String name, dynamic audioUpload, dynamic zipUpload})
const
ProjectSnapshotResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

audioUpload → dynamic
final
createdAtUnix int
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
projectId String
final
projectSnapshotId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zipUpload → dynamic
final

Methods

copyWith({String? projectSnapshotId, String? projectId, int? createdAtUnix, String? name, dynamic audioUpload, dynamic zipUpload}) ProjectSnapshotResponseModel

Available on ProjectSnapshotResponseModel, provided by the $ProjectSnapshotResponseModelExtension extension

copyWithWrapped({Wrapped<String>? projectSnapshotId, Wrapped<String>? projectId, Wrapped<int>? createdAtUnix, Wrapped<String>? name, Wrapped? audioUpload, Wrapped? zipUpload}) ProjectSnapshotResponseModel

Available on ProjectSnapshotResponseModel, provided by the $ProjectSnapshotResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ProjectSnapshotResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ProjectSnapshotResponseModel instance)