PronunciationDictionaryPhonemeRuleRequestModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- PronunciationDictionaryPhonemeRuleRequestModel({required String stringToReplace, required String type, required String phoneme, required String alphabet})
-
const
-
PronunciationDictionaryPhonemeRuleRequestModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
copyWith(
{String? stringToReplace, String? type, String? phoneme, String? alphabet}) → PronunciationDictionaryPhonemeRuleRequestModel -
Available on PronunciationDictionaryPhonemeRuleRequestModel, provided by the $PronunciationDictionaryPhonemeRuleRequestModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? stringToReplace, Wrapped<String> ? type, Wrapped<String> ? phoneme, Wrapped<String> ? alphabet}) → PronunciationDictionaryPhonemeRuleRequestModel -
Available on PronunciationDictionaryPhonemeRuleRequestModel, provided by the $PronunciationDictionaryPhonemeRuleRequestModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const PronunciationDictionaryPhonemeRuleRequestModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(PronunciationDictionaryPhonemeRuleRequestModel instance)