RagChunkMetadata class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- RagChunkMetadata({required String documentId, required String chunkId, required double vectorDistance})
-
const
-
RagChunkMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- chunkId → String
-
final
- documentId → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vectorDistance → double
-
final
Methods
-
copyWith(
{String? documentId, String? chunkId, double? vectorDistance}) → RagChunkMetadata -
Available on RagChunkMetadata, provided by the $RagChunkMetadataExtension extension
-
copyWithWrapped(
{Wrapped< String> ? documentId, Wrapped<String> ? chunkId, Wrapped<double> ? vectorDistance}) → RagChunkMetadata -
Available on RagChunkMetadata, provided by the $RagChunkMetadataExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const RagChunkMetadata Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(RagChunkMetadata instance)