SampleResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SampleResponseModel({required String sampleId, required String fileName, required String mimeType, required int sizeBytes, required String hash, dynamic durationSecs, dynamic removeBackgroundNoise, dynamic hasIsolatedAudio, dynamic hasIsolatedAudioPreview, dynamic speakerSeparation, dynamic trimStart, dynamic trimEnd})
const
SampleResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

durationSecs → dynamic
final
fileName String
final
hash String
final
hashCode int
The hash code for this object.
no setteroverride
hasIsolatedAudio → dynamic
final
hasIsolatedAudioPreview → dynamic
final
mimeType String
final
removeBackgroundNoise → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleId String
final
sizeBytes int
final
speakerSeparation → dynamic
final
trimEnd → dynamic
final
trimStart → dynamic
final

Methods

copyWith({String? sampleId, String? fileName, String? mimeType, int? sizeBytes, String? hash, dynamic durationSecs, dynamic removeBackgroundNoise, dynamic hasIsolatedAudio, dynamic hasIsolatedAudioPreview, dynamic speakerSeparation, dynamic trimStart, dynamic trimEnd}) SampleResponseModel

Available on SampleResponseModel, provided by the $SampleResponseModelExtension extension

copyWithWrapped({Wrapped<String>? sampleId, Wrapped<String>? fileName, Wrapped<String>? mimeType, Wrapped<int>? sizeBytes, Wrapped<String>? hash, Wrapped? durationSecs, Wrapped? removeBackgroundNoise, Wrapped? hasIsolatedAudio, Wrapped? hasIsolatedAudioPreview, Wrapped? speakerSeparation, Wrapped? trimStart, Wrapped? trimEnd}) SampleResponseModel

Available on SampleResponseModel, provided by the $SampleResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SampleResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SampleResponseModel instance)