SpeakerSeparationResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SpeakerSeparationResponseModel({required String voiceId, required String sampleId, required SpeakerSeparationResponseModelStatus status, dynamic speakers, dynamic selectedSpeakerIds})
const
SpeakerSeparationResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleId String
final
selectedSpeakerIds → dynamic
final
speakers → dynamic
final
status SpeakerSeparationResponseModelStatus
final
voiceId String
final

Methods

copyWith({String? voiceId, String? sampleId, SpeakerSeparationResponseModelStatus? status, dynamic speakers, dynamic selectedSpeakerIds}) SpeakerSeparationResponseModel

Available on SpeakerSeparationResponseModel, provided by the $SpeakerSeparationResponseModelExtension extension

copyWithWrapped({Wrapped<String>? voiceId, Wrapped<String>? sampleId, Wrapped<SpeakerSeparationResponseModelStatus>? status, Wrapped? speakers, Wrapped? selectedSpeakerIds}) SpeakerSeparationResponseModel

Available on SpeakerSeparationResponseModel, provided by the $SpeakerSeparationResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SpeakerSeparationResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SpeakerSeparationResponseModel instance)