SubscriptionUsageResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SubscriptionUsageResponseModel({required int rolloverCreditsQuota, required int subscriptionCycleCreditsQuota, required int manuallyGiftedCreditsQuota, required int rolloverCreditsUsed, required int subscriptionCycleCreditsUsed, required int manuallyGiftedCreditsUsed, required int paidUsageBasedCreditsUsed, required int actualReportedCredits})
const
SubscriptionUsageResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

actualReportedCredits int
final
hashCode int
The hash code for this object.
no setteroverride
manuallyGiftedCreditsQuota int
final
manuallyGiftedCreditsUsed int
final
paidUsageBasedCreditsUsed int
final
rolloverCreditsQuota int
final
rolloverCreditsUsed int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionCycleCreditsQuota int
final
subscriptionCycleCreditsUsed int
final

Methods

copyWith({int? rolloverCreditsQuota, int? subscriptionCycleCreditsQuota, int? manuallyGiftedCreditsQuota, int? rolloverCreditsUsed, int? subscriptionCycleCreditsUsed, int? manuallyGiftedCreditsUsed, int? paidUsageBasedCreditsUsed, int? actualReportedCredits}) SubscriptionUsageResponseModel

Available on SubscriptionUsageResponseModel, provided by the $SubscriptionUsageResponseModelExtension extension

copyWithWrapped({Wrapped<int>? rolloverCreditsQuota, Wrapped<int>? subscriptionCycleCreditsQuota, Wrapped<int>? manuallyGiftedCreditsQuota, Wrapped<int>? rolloverCreditsUsed, Wrapped<int>? subscriptionCycleCreditsUsed, Wrapped<int>? manuallyGiftedCreditsUsed, Wrapped<int>? paidUsageBasedCreditsUsed, Wrapped<int>? actualReportedCredits}) SubscriptionUsageResponseModel

Available on SubscriptionUsageResponseModel, provided by the $SubscriptionUsageResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SubscriptionUsageResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SubscriptionUsageResponseModel instance)