SystemToolConfigInput class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SystemToolConfigInput({String? id, required String name, required String description, int? responseTimeoutSecs, String? type, required dynamic params})
const
SystemToolConfigInput.fromJson(Map<String, dynamic> json)
factory

Properties

description String
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
name String
final
params → dynamic
final
responseTimeoutSecs int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

copyWith({String? id, String? name, String? description, int? responseTimeoutSecs, String? type, dynamic params}) SystemToolConfigInput

Available on SystemToolConfigInput, provided by the $SystemToolConfigInputExtension extension

copyWithWrapped({Wrapped<String?>? id, Wrapped<String>? name, Wrapped<String>? description, Wrapped<int?>? responseTimeoutSecs, Wrapped<String?>? type, Wrapped? params}) SystemToolConfigInput

Available on SystemToolConfigInput, provided by the $SystemToolConfigInputExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SystemToolConfigInput Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SystemToolConfigInput instance)