TwilioOutboundCallResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TwilioOutboundCallResponse({required bool success, required String message, required dynamic conversationId, required dynamic callSid})
const
TwilioOutboundCallResponse.fromJson(Map<String, dynamic> json)
factory

Properties

callSid → dynamic
final
conversationId → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

copyWith({bool? success, String? message, dynamic conversationId, dynamic callSid}) TwilioOutboundCallResponse

Available on TwilioOutboundCallResponse, provided by the $TwilioOutboundCallResponseExtension extension

copyWithWrapped({Wrapped<bool>? success, Wrapped<String>? message, Wrapped? conversationId, Wrapped? callSid}) TwilioOutboundCallResponse

Available on TwilioOutboundCallResponse, provided by the $TwilioOutboundCallResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TwilioOutboundCallResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TwilioOutboundCallResponse instance)