VoicePreviewResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VoicePreviewResponseModel({required String audioBase64, required String generatedVoiceId, required String mediaType, required double durationSecs})
const
VoicePreviewResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

audioBase64 String
final
durationSecs double
final
generatedVoiceId String
final
hashCode int
The hash code for this object.
no setteroverride
mediaType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? audioBase64, String? generatedVoiceId, String? mediaType, double? durationSecs}) VoicePreviewResponseModel

Available on VoicePreviewResponseModel, provided by the $VoicePreviewResponseModelExtension extension

copyWithWrapped({Wrapped<String>? audioBase64, Wrapped<String>? generatedVoiceId, Wrapped<String>? mediaType, Wrapped<double>? durationSecs}) VoicePreviewResponseModel

Available on VoicePreviewResponseModel, provided by the $VoicePreviewResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const VoicePreviewResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VoicePreviewResponseModel instance)