VoiceSamplePreviewResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VoiceSamplePreviewResponseModel({required String audioBase64, required String voiceId, required String sampleId, required String mediaType, dynamic durationSecs})
const
VoiceSamplePreviewResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

audioBase64 String
final
durationSecs → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
mediaType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleId String
final
voiceId String
final

Methods

copyWith({String? audioBase64, String? voiceId, String? sampleId, String? mediaType, dynamic durationSecs}) VoiceSamplePreviewResponseModel

Available on VoiceSamplePreviewResponseModel, provided by the $VoiceSamplePreviewResponseModelExtension extension

copyWithWrapped({Wrapped<String>? audioBase64, Wrapped<String>? voiceId, Wrapped<String>? sampleId, Wrapped<String>? mediaType, Wrapped? durationSecs}) VoiceSamplePreviewResponseModel

Available on VoiceSamplePreviewResponseModel, provided by the $VoiceSamplePreviewResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const VoiceSamplePreviewResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VoiceSamplePreviewResponseModel instance)