VoiceSampleVisualWaveformResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VoiceSampleVisualWaveformResponseModel({required String sampleId, required List<double> visualWaveform})
const
VoiceSampleVisualWaveformResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleId String
final
visualWaveform List<double>
final

Methods

copyWith({String? sampleId, List<double>? visualWaveform}) VoiceSampleVisualWaveformResponseModel

Available on VoiceSampleVisualWaveformResponseModel, provided by the $VoiceSampleVisualWaveformResponseModelExtension extension

copyWithWrapped({Wrapped<String>? sampleId, Wrapped<List<double>>? visualWaveform}) VoiceSampleVisualWaveformResponseModel

Available on VoiceSampleVisualWaveformResponseModel, provided by the $VoiceSampleVisualWaveformResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const VoiceSampleVisualWaveformResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VoiceSampleVisualWaveformResponseModel instance)