VoiceVerificationResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VoiceVerificationResponseModel({required bool requiresVerification, required bool isVerified, required List<String> verificationFailures, required int verificationAttemptsCount, dynamic language, dynamic verificationAttempts})
const
VoiceVerificationResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isVerified bool
final
language → dynamic
final
requiresVerification bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verificationAttempts → dynamic
final
verificationAttemptsCount int
final
verificationFailures List<String>
final

Methods

copyWith({bool? requiresVerification, bool? isVerified, List<String>? verificationFailures, int? verificationAttemptsCount, dynamic language, dynamic verificationAttempts}) VoiceVerificationResponseModel

Available on VoiceVerificationResponseModel, provided by the $VoiceVerificationResponseModelExtension extension

copyWithWrapped({Wrapped<bool>? requiresVerification, Wrapped<bool>? isVerified, Wrapped<List<String>>? verificationFailures, Wrapped<int>? verificationAttemptsCount, Wrapped? language, Wrapped? verificationAttempts}) VoiceVerificationResponseModel

Available on VoiceVerificationResponseModel, provided by the $VoiceVerificationResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const VoiceVerificationResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VoiceVerificationResponseModel instance)