v1VoicesVoiceIdSamplesSampleIdAudioGet method
Get Audio From Sample @param voice_id Voice ID to be used, you can use https://api.elevenlabs.io/v1/voices to list all the available voices. @param sample_id Sample ID to be used, you can use GET https://api.elevenlabs.io/v1/voices/{voice_id} to list all the available samples for a voice. @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
Future<chopper.Response> v1VoicesVoiceIdSamplesSampleIdAudioGet({
required String? voiceId,
required String? sampleId,
String? xiApiKey,
}) {
return _v1VoicesVoiceIdSamplesSampleIdAudioGet(
voiceId: voiceId,
sampleId: sampleId,
xiApiKey: xiApiKey?.toString(),
);
}