AgentSummaryResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
AgentSummaryResponseModel({required String agentId, required String name, required List<
String> tags, required int createdAtUnixSecs, required ResourceAccessInfo accessInfo}) -
const
-
AgentSummaryResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessInfo → ResourceAccessInfo
-
final
- agentId → String
-
final
- createdAtUnixSecs → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
Methods
-
copyWith(
{String? agentId, String? name, List< String> ? tags, int? createdAtUnixSecs, ResourceAccessInfo? accessInfo}) → AgentSummaryResponseModel -
Available on AgentSummaryResponseModel, provided by the $AgentSummaryResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? agentId, Wrapped<String> ? name, Wrapped<List< ? tags, Wrapped<String> >int> ? createdAtUnixSecs, Wrapped<ResourceAccessInfo> ? accessInfo}) → AgentSummaryResponseModel -
Available on AgentSummaryResponseModel, provided by the $AgentSummaryResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const AgentSummaryResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(AgentSummaryResponseModel instance)