ArrayJsonSchemaPropertyInput class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ArrayJsonSchemaPropertyInput({String? type, String? description, required dynamic items})
-
const
-
ArrayJsonSchemaPropertyInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- items → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
Methods
-
copyWith(
{String? type, String? description, dynamic items}) → ArrayJsonSchemaPropertyInput -
Available on ArrayJsonSchemaPropertyInput, provided by the $ArrayJsonSchemaPropertyInputExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? type, Wrapped<String?> ? description, Wrapped? items}) → ArrayJsonSchemaPropertyInput -
Available on ArrayJsonSchemaPropertyInput, provided by the $ArrayJsonSchemaPropertyInputExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ArrayJsonSchemaPropertyInput Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ArrayJsonSchemaPropertyInput instance)