AudioNativeEditContentResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- AudioNativeEditContentResponseModel({required String projectId, required bool converting, required bool publishing, required String htmlSnippet})
-
const
-
AudioNativeEditContentResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- converting → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- htmlSnippet → String
-
final
- projectId → String
-
final
- publishing → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? projectId, bool? converting, bool? publishing, String? htmlSnippet}) → AudioNativeEditContentResponseModel -
Available on AudioNativeEditContentResponseModel, provided by the $AudioNativeEditContentResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? projectId, Wrapped<bool> ? converting, Wrapped<bool> ? publishing, Wrapped<String> ? htmlSnippet}) → AudioNativeEditContentResponseModel -
Available on AudioNativeEditContentResponseModel, provided by the $AudioNativeEditContentResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const AudioNativeEditContentResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(AudioNativeEditContentResponseModel instance)