BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost({required List<
String> files, bool? removeBackgroundNoise}) -
const
-
BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
files
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- removeBackgroundNoise → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< String> ? files, bool? removeBackgroundNoise}) → BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost -
Available on BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost, provided by the $BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPostExtension extension
-
copyWithWrapped(
{Wrapped< List< ? files, Wrapped<String> >bool?> ? removeBackgroundNoise}) → BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost -
Available on BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost, provided by the $BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPostExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(BodyAddSamplesToPVCVoiceV1VoicesPvcVoiceIdSamplesPost instance)