BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost({required List<
DialogueInput> inputs, String? modelId, dynamic settings, dynamic pronunciationDictionaryLocators, dynamic seed}) -
const
-
BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
inputs
→ List<
DialogueInput> -
final
- modelId → String?
-
final
- pronunciationDictionaryLocators → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → dynamic
-
final
- settings → dynamic
-
final
Methods
-
copyWith(
{List< DialogueInput> ? inputs, String? modelId, dynamic settings, dynamic pronunciationDictionaryLocators, dynamic seed}) → BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost -
Available on BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost, provided by the $BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPostExtension extension
-
copyWithWrapped(
{Wrapped< List< ? inputs, Wrapped<DialogueInput> >String?> ? modelId, Wrapped? settings, Wrapped? pronunciationDictionaryLocators, Wrapped? seed}) → BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost -
Available on BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost, provided by the $BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPostExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(BodyTextToDialogueMultiVoiceStreamingV1TextToDialogueStreamPost instance)