BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost({required String text, String? modelId, dynamic languageCode, dynamic voiceSettings, dynamic pronunciationDictionaryLocators, dynamic seed, dynamic previousText, dynamic nextText, dynamic previousRequestIds, dynamic nextRequestIds, bool? usePvcAsIvc, BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization? applyTextNormalization, bool? applyLanguageTextNormalization})
-
const
-
BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost.fromJson(Map<
String, dynamic> json) -
factory
Properties
- applyLanguageTextNormalization → bool?
-
final
- applyTextNormalization → BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → dynamic
-
final
- modelId → String?
-
final
- nextRequestIds → dynamic
-
final
- nextText → dynamic
-
final
- previousRequestIds → dynamic
-
final
- previousText → dynamic
-
final
- pronunciationDictionaryLocators → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → dynamic
-
final
- text → String
-
final
- usePvcAsIvc → bool?
-
final
- voiceSettings → dynamic
-
final
Methods
-
copyWith(
{String? text, String? modelId, dynamic languageCode, dynamic voiceSettings, dynamic pronunciationDictionaryLocators, dynamic seed, dynamic previousText, dynamic nextText, dynamic previousRequestIds, dynamic nextRequestIds, bool? usePvcAsIvc, BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization? applyTextNormalization, bool? applyLanguageTextNormalization}) → BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost -
Available on BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost, provided by the $BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostExtension extension
-
copyWithWrapped(
{Wrapped< String> ? text, Wrapped<String?> ? modelId, Wrapped? languageCode, Wrapped? voiceSettings, Wrapped? pronunciationDictionaryLocators, Wrapped? seed, Wrapped? previousText, Wrapped? nextText, Wrapped? previousRequestIds, Wrapped? nextRequestIds, Wrapped<bool?> ? usePvcAsIvc, Wrapped<BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization?> ? applyTextNormalization, Wrapped<bool?> ? applyLanguageTextNormalization}) → BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost -
Available on BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost, provided by the $BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
-
fromJsonFactory
→ const BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPost instance)