ConversationHistoryTranscriptToolCallCommonModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ConversationHistoryTranscriptToolCallCommonModel({dynamic type, required String requestId, required String toolName, required String paramsAsJson, required bool toolHasBeenCalled, dynamic toolDetails})
-
const
-
ConversationHistoryTranscriptToolCallCommonModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- paramsAsJson → String
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolDetails → dynamic
-
final
- toolHasBeenCalled → bool
-
final
- toolName → String
-
final
- type → dynamic
-
final
Methods
-
copyWith(
{dynamic type, String? requestId, String? toolName, String? paramsAsJson, bool? toolHasBeenCalled, dynamic toolDetails}) → ConversationHistoryTranscriptToolCallCommonModel -
Available on ConversationHistoryTranscriptToolCallCommonModel, provided by the $ConversationHistoryTranscriptToolCallCommonModelExtension extension
-
copyWithWrapped(
{Wrapped? type, Wrapped< String> ? requestId, Wrapped<String> ? toolName, Wrapped<String> ? paramsAsJson, Wrapped<bool> ? toolHasBeenCalled, Wrapped? toolDetails}) → ConversationHistoryTranscriptToolCallCommonModel -
Available on ConversationHistoryTranscriptToolCallCommonModel, provided by the $ConversationHistoryTranscriptToolCallCommonModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationHistoryTranscriptToolCallCommonModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationHistoryTranscriptToolCallCommonModel instance)