ConversationHistoryTranscriptToolResultCommonModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ConversationHistoryTranscriptToolResultCommonModel({dynamic type, required String requestId, required String toolName, required String resultValue, required bool isError, required bool toolHasBeenCalled, double? toolLatencySecs})
-
const
-
ConversationHistoryTranscriptToolResultCommonModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isError → bool
-
final
- requestId → String
-
final
- resultValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolHasBeenCalled → bool
-
final
- toolLatencySecs → double?
-
final
- toolName → String
-
final
- type → dynamic
-
final
Methods
-
copyWith(
{dynamic type, String? requestId, String? toolName, String? resultValue, bool? isError, bool? toolHasBeenCalled, double? toolLatencySecs}) → ConversationHistoryTranscriptToolResultCommonModel -
Available on ConversationHistoryTranscriptToolResultCommonModel, provided by the $ConversationHistoryTranscriptToolResultCommonModelExtension extension
-
copyWithWrapped(
{Wrapped? type, Wrapped< String> ? requestId, Wrapped<String> ? toolName, Wrapped<String> ? resultValue, Wrapped<bool> ? isError, Wrapped<bool> ? toolHasBeenCalled, Wrapped<double?> ? toolLatencySecs}) → ConversationHistoryTranscriptToolResultCommonModel -
Available on ConversationHistoryTranscriptToolResultCommonModel, provided by the $ConversationHistoryTranscriptToolResultCommonModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationHistoryTranscriptToolResultCommonModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationHistoryTranscriptToolResultCommonModel instance)