FeedbackResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
Properties
- audioQuality → bool
-
final
- emotions → bool
-
final
- feedback → String
-
final
- glitches → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inaccurateClone → bool
-
final
- other → bool
-
final
- reviewStatus → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbsUp → bool
-
final
Methods
-
copyWith(
{bool? thumbsUp, String? feedback, bool? emotions, bool? inaccurateClone, bool? glitches, bool? audioQuality, bool? other, String? reviewStatus}) → FeedbackResponseModel -
Available on FeedbackResponseModel, provided by the $FeedbackResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< bool> ? thumbsUp, Wrapped<String> ? feedback, Wrapped<bool> ? emotions, Wrapped<bool> ? inaccurateClone, Wrapped<bool> ? glitches, Wrapped<bool> ? audioQuality, Wrapped<bool> ? other, Wrapped<String?> ? reviewStatus}) → FeedbackResponseModel -
Available on FeedbackResponseModel, provided by the $FeedbackResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const FeedbackResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(FeedbackResponseModel instance)