GetConversationsPageResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
GetConversationsPageResponseModel({required List<
ConversationSummaryResponseModel> conversations, dynamic nextCursor, required bool hasMore}) -
const
-
GetConversationsPageResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
conversations
→ List<
ConversationSummaryResponseModel> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasMore → bool
-
final
- nextCursor → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< ConversationSummaryResponseModel> ? conversations, dynamic nextCursor, bool? hasMore}) → GetConversationsPageResponseModel -
Available on GetConversationsPageResponseModel, provided by the $GetConversationsPageResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< List< ? conversations, Wrapped? nextCursor, Wrapped<ConversationSummaryResponseModel> >bool> ? hasMore}) → GetConversationsPageResponseModel -
Available on GetConversationsPageResponseModel, provided by the $GetConversationsPageResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const GetConversationsPageResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(GetConversationsPageResponseModel instance)