KnowledgeBaseDocumentMetadataResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- KnowledgeBaseDocumentMetadataResponseModel({required int createdAtUnixSecs, required int lastUpdatedAtUnixSecs, required int sizeBytes})
-
const
-
KnowledgeBaseDocumentMetadataResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAtUnixSecs → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastUpdatedAtUnixSecs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
final
Methods
-
copyWith(
{int? createdAtUnixSecs, int? lastUpdatedAtUnixSecs, int? sizeBytes}) → KnowledgeBaseDocumentMetadataResponseModel -
Available on KnowledgeBaseDocumentMetadataResponseModel, provided by the $KnowledgeBaseDocumentMetadataResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< int> ? createdAtUnixSecs, Wrapped<int> ? lastUpdatedAtUnixSecs, Wrapped<int> ? sizeBytes}) → KnowledgeBaseDocumentMetadataResponseModel -
Available on KnowledgeBaseDocumentMetadataResponseModel, provided by the $KnowledgeBaseDocumentMetadataResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const KnowledgeBaseDocumentMetadataResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(KnowledgeBaseDocumentMetadataResponseModel instance)