LanguageResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- LanguageResponseModel({required String languageId, required String name})
-
const
-
LanguageResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageId → String
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languageId, String? name}) → LanguageResponseModel -
Available on LanguageResponseModel, provided by the $LanguageResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? languageId, Wrapped<String> ? name}) → LanguageResponseModel -
Available on LanguageResponseModel, provided by the $LanguageResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const LanguageResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(LanguageResponseModel instance)