ProjectSnapshotExtendedResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ProjectSnapshotExtendedResponseModel({required String projectSnapshotId, required String projectId, required int createdAtUnix, required String name, dynamic audioUpload, dynamic zipUpload, required List<
CharacterAlignmentModel> characterAlignments}) -
const
-
ProjectSnapshotExtendedResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- audioUpload → dynamic
-
final
-
characterAlignments
→ List<
CharacterAlignmentModel> -
final
- createdAtUnix → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- projectId → String
-
final
- projectSnapshotId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zipUpload → dynamic
-
final
Methods
-
copyWith(
{String? projectSnapshotId, String? projectId, int? createdAtUnix, String? name, dynamic audioUpload, dynamic zipUpload, List< CharacterAlignmentModel> ? characterAlignments}) → ProjectSnapshotExtendedResponseModel -
Available on ProjectSnapshotExtendedResponseModel, provided by the $ProjectSnapshotExtendedResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? projectSnapshotId, Wrapped<String> ? projectId, Wrapped<int> ? createdAtUnix, Wrapped<String> ? name, Wrapped? audioUpload, Wrapped? zipUpload, Wrapped<List< ? characterAlignments}) → ProjectSnapshotExtendedResponseModelCharacterAlignmentModel> > -
Available on ProjectSnapshotExtendedResponseModel, provided by the $ProjectSnapshotExtendedResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ProjectSnapshotExtendedResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ProjectSnapshotExtendedResponseModel instance)