SafetyResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- SafetyResponseModel({bool? isBlockedIvc, bool? isBlockedNonIvc, bool? ignoreSafetyEvaluation})
-
const
-
SafetyResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- ignoreSafetyEvaluation → bool?
-
final
- isBlockedIvc → bool?
-
final
- isBlockedNonIvc → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isBlockedIvc, bool? isBlockedNonIvc, bool? ignoreSafetyEvaluation}) → SafetyResponseModel -
Available on SafetyResponseModel, provided by the $SafetyResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? isBlockedIvc, Wrapped<bool?> ? isBlockedNonIvc, Wrapped<bool?> ? ignoreSafetyEvaluation}) → SafetyResponseModel -
Available on SafetyResponseModel, provided by the $SafetyResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const SafetyResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(SafetyResponseModel instance)