SpeechHistoryItemResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- SpeechHistoryItemResponseModel({required String historyItemId, dynamic requestId, dynamic voiceId, dynamic modelId, dynamic voiceName, dynamic voiceCategory, dynamic text, required int dateUnix, required int characterCountChangeFrom, required int characterCountChangeTo, required String contentType, required SpeechHistoryItemResponseModelState state, dynamic settings, dynamic feedback, dynamic source, dynamic alignments, dynamic dialogue})
-
const
-
SpeechHistoryItemResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- alignments → dynamic
-
final
- characterCountChangeFrom → int
-
final
- characterCountChangeTo → int
-
final
- contentType → String
-
final
- dateUnix → int
-
final
- dialogue → dynamic
-
final
- feedback → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- historyItemId → String
-
final
- modelId → dynamic
-
final
- requestId → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → dynamic
-
final
-
final
- source → dynamic
-
final
- state → SpeechHistoryItemResponseModelState
-
final
- text → dynamic
-
final
- voiceCategory → dynamic
-
final
- voiceId → dynamic
-
final
- voiceName → dynamic
-
final
Methods
-
copyWith(
{String? historyItemId, dynamic requestId, dynamic voiceId, dynamic modelId, dynamic voiceName, dynamic voiceCategory, dynamic text, int? dateUnix, int? characterCountChangeFrom, int? characterCountChangeTo, String? contentType, SpeechHistoryItemResponseModelState? state, dynamic settings, dynamic feedback, dynamic source, dynamic alignments, dynamic dialogue}) → SpeechHistoryItemResponseModel -
Available on SpeechHistoryItemResponseModel, provided by the $SpeechHistoryItemResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? historyItemId, Wrapped? requestId, Wrapped? voiceId, Wrapped? modelId, Wrapped? voiceName, Wrapped? voiceCategory, Wrapped? text, Wrapped<int> ? dateUnix, Wrapped<int> ? characterCountChangeFrom, Wrapped<int> ? characterCountChangeTo, Wrapped<String> ? contentType, Wrapped<SpeechHistoryItemResponseModelState> ? state, Wrapped? settings, Wrapped? feedback, Wrapped? source, Wrapped? alignments, Wrapped? dialogue}) → SpeechHistoryItemResponseModel -
Available on SpeechHistoryItemResponseModel, provided by the $SpeechHistoryItemResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const SpeechHistoryItemResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(SpeechHistoryItemResponseModel instance)