UserResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- UserResponseModel({required String userId, required SubscriptionResponseModel subscription, dynamic subscriptionExtras, required bool isNewUser, dynamic xiApiKey, required bool canUseDelayedPaymentMethods, required bool isOnboardingCompleted, required bool isOnboardingChecklistCompleted, dynamic firstName, bool? isApiKeyHashed, dynamic xiApiKeyPreview, dynamic referralLinkCode, dynamic partnerstackPartnerDefaultLink})
-
const
-
UserResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- canUseDelayedPaymentMethods → bool
-
final
- firstName → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isApiKeyHashed → bool?
-
final
- isNewUser → bool
-
final
- isOnboardingChecklistCompleted → bool
-
final
- isOnboardingCompleted → bool
-
final
- partnerstackPartnerDefaultLink → dynamic
-
final
- referralLinkCode → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription → SubscriptionResponseModel
-
final
- subscriptionExtras → dynamic
-
final
- userId → String
-
final
- xiApiKey → dynamic
-
final
- xiApiKeyPreview → dynamic
-
final
Methods
-
copyWith(
{String? userId, SubscriptionResponseModel? subscription, dynamic subscriptionExtras, bool? isNewUser, dynamic xiApiKey, bool? canUseDelayedPaymentMethods, bool? isOnboardingCompleted, bool? isOnboardingChecklistCompleted, dynamic firstName, bool? isApiKeyHashed, dynamic xiApiKeyPreview, dynamic referralLinkCode, dynamic partnerstackPartnerDefaultLink}) → UserResponseModel -
Available on UserResponseModel, provided by the $UserResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? userId, Wrapped<SubscriptionResponseModel> ? subscription, Wrapped? subscriptionExtras, Wrapped<bool> ? isNewUser, Wrapped? xiApiKey, Wrapped<bool> ? canUseDelayedPaymentMethods, Wrapped<bool> ? isOnboardingCompleted, Wrapped<bool> ? isOnboardingChecklistCompleted, Wrapped? firstName, Wrapped<bool?> ? isApiKeyHashed, Wrapped? xiApiKeyPreview, Wrapped? referralLinkCode, Wrapped? partnerstackPartnerDefaultLink}) → UserResponseModel -
Available on UserResponseModel, provided by the $UserResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const UserResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(UserResponseModel instance)